@@ -1,4 +1,4 @@
-#-----------------------------------------------------------------
+# -----------------------------------------------------------------
 # pycparser: func_defs_add_param.py
 #
 # Example of rewriting AST nodes to add parameters to function
@@ -6,11 +6,10 @@
 #
 # Eli Bendersky [https://eli.thegreenplace.net/]
 # License: BSD
-#-----------------------------------------------------------------
-from __future__ import print_function
-
+# -----------------------------------------------------------------
 import sys
-sys.path.extend(['.', '..'])
+
+sys.path.extend([".", ".."])
 
 from pycparser import c_parser, c_ast, c_generator
 
@@ -24,28 +23,28 @@ void bar() {
 
 
 class ParamAdder(c_ast.NodeVisitor):
-    def visit_FuncDecl(self, node):
-        ty = c_ast.TypeDecl(declname='_hidden',
-                            quals=[],
-                            align=[],
-                            type=c_ast.IdentifierType(['int']))
+    def visit_FuncDecl(self, node: c_ast.FuncDecl) -> None:
+        ty = c_ast.TypeDecl(
+            declname="_hidden", quals=[], align=[], type=c_ast.IdentifierType(["int"])
+        )
         newdecl = c_ast.Decl(
-                    name='_hidden',
-                    quals=[],
-                    align=[],
-                    storage=[],
-                    funcspec=[],
-                    type=ty,
-                    init=None,
-                    bitsize=None,
-                    coord=node.coord)
-        if node.args:
+            name="_hidden",
+            quals=[],
+            align=[],
+            storage=[],
+            funcspec=[],
+            type=ty,
+            init=None,
+            bitsize=None,
+            coord=node.coord,
+        )
+        if node.args is not None:
             node.args.params.append(newdecl)
         else:
             node.args = c_ast.ParamList(params=[newdecl])
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     parser = c_parser.CParser()
     ast = parser.parse(text)
     print("AST before change:")
